%define         majornum       8
%define         libname        %mklibname %{name} %{majornum}
%define         develname      %mklibname %{name} -d

%bcond_without  dnstap
%bcond_without  doh
%bcond_without  redis

Name:           unbound
Version:        1.23.0
Release:        %mkrel 1
Summary:        A validating, recursive, and caching DNS resolver

License:        BSD
Group:          Networking/Other
Url:            https://unbound.net

Source0:        https://nlnetlabs.nl/downloads/unbound/%{name}-%{version}.tar.gz
Source1:        %{name}-tmpfiles.conf
Source2:        %{name}.service
Source3:        %{name}_mga.conf
Source4:        README.urpmi


BuildRequires:  bison
BuildRequires:  doxygen
BuildRequires:  flex
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(nss)
%if %{with redis}
BuildRequires:  pkgconfig(hiredis)
%endif
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libmnl)
%if %{with doh}
BuildRequires:	pkgconfig(libnghttp2)
%endif
%if %{with dnstap}
BuildRequires:	pkgconfig(libprotobuf-c)
%endif
#
# For Python bindings
BuildRequires:  pkgconfig(python3)
BuildRequires:  swig

Requires(pre):    rpm-helper >= %{rpmhelper_required_version}
Requires(post):   rpm-helper >= %{rpmhelper_required_version}
Requires(preun):  rpm-helper >= %{rpmhelper_required_version}
Requires(postun): rpm-helper >= %{rpmhelper_required_version}

%description
Unbound is a validating, recursive, and caching DNS resolver. The C
implementation of Unbound is developed and maintained by NLnet
Labs. It is based on ideas and algorithms taken from a java prototype
developed by Verisign labs, Nominet, Kirei and ep.net. Unbound is
designed as a set of modular components, so that also DNSSEC (secure
DNS) validation and stub-resolvers (that do not run as a server, but
are linked into an application) are easily possible.


%package -n %{libname}
Summary:        Shared libraries for Unbound  
Group:          System/Libraries
Provides:       lib%{name} = %{version}-%{release}
Provides:       lib%{name}%{?_isa} = %{version}-%{release}

%description -n %{libname}
%{summary}.


%package -n %{develname}
Summary:        Development headers and libraries for Unbound
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
%{summary}.

%package -n python3-unbound
Summary:        Python 3 modules and extensions for unbound
Group:          Development/Python
%{?python_provide:%python_provide python3-unbound}
Requires:       lib%{name}%{?_isa} = %{version}-%{release}

%description -n python3-unbound
Python 3 modules and extensions for unbound


%prep
%autosetup -p1 -n %{name}-%{version}

%build
export PYTHON=%__python3
%configure \
	--disable-rpath \
	--disable-static \
	--with-libevent \
	--enable-event-api \
	--with-pythonmodule \
	--with-pyunbound \
	--with-pidfile=%{_rundir}/unbound.pid \
	--enable-ipset \
%if %{with dnstap}
	--enable-dnstap \
%endif
%if %{with doh}
	--with-libnghttp2 \
%endif
%if %{with redis}
	--enable-cachedb \
	--with-libhiredis \
%endif
	--enable-tfo-client \
	--enable-tfo-server
	
%make_build

%install
%make_install

%{__install} -m644 %{SOURCE4} README.urpmi
 
%{__install} -D -p -m 0644  %{buildroot}%{_sysconfdir}/%{name}/unbound.conf %{buildroot}%{_docdir}/%{name}/unbound.conf
%{__install} -D -p -m 0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
%{__install} -D -p -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

find %{buildroot}%{_libdir} -name '*.la' -delete

%pre
%_pre_useradd %{name} /dev/null /bin/false

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel %{name}

%files
%doc README README.urpmi
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/*.conf
%{_sbindir}/%{name}*
%{_docdir}/%{name}/unbound.conf
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man5/%{name}*.5*
%{_mandir}/man8/%{name}*.8*

%files -n %{libname}
%license doc/LICENSE
%{_libdir}/lib%{name}.so.%{majornum}{,.*}

%files -n %{develname}
%{_includedir}/*.h
%{_libdir}/lib%{name}*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3.*

%files -n python3-unbound
%license pythonmod/LICENSE
%{python3_sitearch}/*
%doc libunbound/python/examples/*
%doc pythonmod/examples/*


%changelog
* Wed Jul 02 2025 eatdirt <eatdirt> 1.23.0-1.mga10
+ Revision: 2242728
- Update to version 1.23.0

* Wed Jul 02 2025 umeabot <umeabot> 1.22.0-3.mga10
+ Revision: 2237183
- Mageia 10 Mass Rebuild

* Wed Feb 26 2025 wally <wally> 1.22.0-2.mga10
+ Revision: 2152840
- rebuild for python3.13

* Wed Dec 04 2024 eatdirt <eatdirt> 1.22.0-1.mga10
+ Revision: 2121608
- Update to version 1.22.0

* Sun Oct 20 2024 eatdirt <eatdirt> 1.21.1-2.mga10
+ Revision: 2109128
- Enable dnstap, doh and redis options

* Tue Oct 15 2024 eatdirt <eatdirt> 1.21.1-1.mga10
+ Revision: 2107019
- Update to version 1.21.1

* Thu Sep 05 2024 eatdirt <eatdirt> 1.21.0-1.mga10
+ Revision: 2093201
- Update to version 1.21.0

* Fri May 31 2024 eatdirt <eatdirt> 1.20.0-1.mga10
+ Revision: 2069009
- Update to version 1.20.0

* Fri Mar 29 2024 daviddavid <daviddavid> 1.19.3-1.mga10
+ Revision: 2053086
- new version: 1.19.3
- enable hiredis support

* Wed Feb 14 2024 eatdirt <eatdirt> 1.19.1-1.mga10
+ Revision: 2041301
- Update to version 1.19.1

* Fri Dec 29 2023 daviddavid <daviddavid> 1.17.1-4.mga10
+ Revision: 2023944
- rebuild for py3.12

* Thu Dec 07 2023 wally <wally> 1.17.1-3.mga10
+ Revision: 2015140
- rebuild for py3.12
- add libunbound provides to lib pkg

* Sat Apr 01 2023 squidf <squidf> 1.17.1-2.mga9
+ Revision: 1951108
- Make optional dnscrypt-proxy configuration (mga#31728)

* Fri Jan 20 2023 eatdirt <eatdirt> 1.17.1-1.mga9
+ Revision: 1934477
- Update to version 1.17.1

* Sat Dec 03 2022 eatdirt <eatdirt> 1.17.0-1.mga9
+ Revision: 1916119
- Update to version 1.17.0

* Tue Sep 27 2022 squidf <squidf> 1.16.3-1.mga9
+ Revision: 1892778
- New version: 1.16.3 (mga#30876)

* Sun Aug 21 2022 squidf <squidf> 1.16.2-1.mga9
+ Revision: 1878984
- New version: 1.16.2

* Thu May 05 2022 eatdirt <eatdirt> 1.15.0-1.mga9
+ Revision: 1856353
- Upgrade to version 1.15.0

* Sat Mar 26 2022 umeabot <umeabot> 1.13.2-4.mga9
+ Revision: 1827798
- Mageia 9 Mass Rebuild

* Sat Feb 12 2022 neoclust <neoclust> 1.13.2-3.mga9
+ Revision: 1773226
- Rebuild against python 3.10

* Sat Oct 02 2021 wally <wally> 1.13.2-2.mga9
+ Revision: 1747435
- rebuild for openssl 3.0.0

* Fri Aug 27 2021 eatdirt <eatdirt> 1.13.2-1.mga9
+ Revision: 1742895
- Update to version 1.13.2

* Tue Mar 16 2021 tmb <tmb> 1.13.0-3.mga9
+ Revision: 1703831
- rebuild for python 3.9

* Sun Dec 13 2020 eatdirt <eatdirt> 1.13.0-2.mga8
+ Revision: 1656065
- Enable ipset module

* Tue Dec 08 2020 eatdirt <eatdirt> 1.13.0-1.mga8
+ Revision: 1654338
- Upgrade to version 1.13.0

* Fri Oct 09 2020 eatdirt <eatdirt> 1.12.0-1.mga8
+ Revision: 1633015
- Upgrade to version 1.12.0

* Fri Sep 04 2020 eatdirt <eatdirt> 1.11.0-1.mga8
+ Revision: 1621645
- Upgrade to version 1.11.0

* Tue May 19 2020 neoclust <neoclust> 1.10.1-1.mga8
+ Revision: 1586270
- New version 1.10.1 Fixing CVE-2020-126623 and CVE-2020-12663

* Wed Mar 18 2020 eatdirt <eatdirt> 1.10.0-1.mga8
+ Revision: 1557862
- Upgrade to version 1.10.0

* Wed Feb 19 2020 umeabot <umeabot> 1.9.6-3.mga8
+ Revision: 1543019
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 11 2020 wally <wally> 1.9.6-2.mga8
+ Revision: 1477558
- drop python2 support
+ eatdirt <eatdirt>
- Upgrade to version 1.9.6

* Wed Nov 20 2019 eatdirt <eatdirt> 1.9.5-1.mga8
+ Revision: 1461828
- Upgrade to version 1.9.5

* Tue Nov 05 2019 eatdirt <eatdirt> 1.9.4-1.mga8
+ Revision: 1458037
- Upgrade to version 1.9.4, fixing mga#25639

* Thu Sep 12 2019 tv <tv> 1.9.1-3.mga8
+ Revision: 1440063
- rebuild for python-3.8

* Wed May 29 2019 eatdirt <eatdirt> 1.9.1-2.mga8
+ Revision: 1399387
- Enable event API

* Sat Apr 06 2019 eatdirt <eatdirt> 1.9.1-1.mga7
+ Revision: 1386404
- Upgrade to version 1.9.1

* Thu Mar 07 2019 eatdirt <eatdirt> 1.9.0-1.mga7
+ Revision: 1372212
- Upgrade to version 1.9.0

* Sun Jan 06 2019 kekepower <kekepower> 1.8.3-2.mga7
+ Revision: 1350229
- Rebuild for Python 3.7

* Fri Dec 14 2018 eatdirt <eatdirt> 1.8.3-1.mga7
+ Revision: 1341204
- Upgrade to version 1.8.3

* Tue Oct 16 2018 ngompa <ngompa> 1.8.1-2.mga7
+ Revision: 1320725
- Build Python bindings

* Tue Oct 09 2018 eatdirt <eatdirt> 1.8.1-1.mga7
+ Revision: 1319086
- Upgrade to version 1.8.1

* Sun Sep 23 2018 umeabot <umeabot> 1.7.3-2.mga7
+ Revision: 1301516
- Mageia 7 Mass Rebuild

* Sun Jun 24 2018 eatdirt <eatdirt> 1.7.3-1.mga7
+ Revision: 1239387
- Upgrade to version 1.7.3

* Sun May 13 2018 eatdirt <eatdirt> 1.7.1-1.mga7
+ Revision: 1228999
- Upgrade to version 1.7.1

* Thu Mar 15 2018 eatdirt <eatdirt> 1.7.0-1.mga7
+ Revision: 1209592
- Upgrade to version 1.7.0

* Fri Jan 19 2018 eatdirt <eatdirt> 1.6.8-1.mga7
+ Revision: 1194716
- Upgrade to version 1.6.8

* Wed Nov 15 2017 eatdirt <eatdirt> 1.6.7-1.mga7
+ Revision: 1177489
- Upgrade to version 1.6.7

* Sat Oct 07 2017 eatdirt <eatdirt> 1.6.6-1.mga7
+ Revision: 1169875
- Upgrade to version 1.6.6

* Sun Aug 27 2017 guillomovitch <guillomovitch> 1.6.2-2.mga7
+ Revision: 1148287
- rebuild for latest openssl

* Tue May 02 2017 eatdirt <eatdirt> 1.6.2-1.mga6
+ Revision: 1098561
- Upgrade to version 1.6.2

* Fri Mar 03 2017 eatdirt <eatdirt> 1.6.1-1.mga6
+ Revision: 1088567
- Upgrade to version 1.6.1

* Thu Feb 16 2017 mrambo3501 <mrambo3501> 1.6.0-2.mga6
+ Revision: 1086428
- rebuild for new libevent

* Fri Jan 13 2017 eatdirt <eatdirt> 1.6.0-1.mga6
+ Revision: 1081496
- Upgrade to version 1.6.0

* Mon Oct 10 2016 eatdirt <eatdirt> 1.5.10-1.mga6
+ Revision: 1059961
- Upgrading unbound to 1.5.10

* Wed Jun 22 2016 eatdirt <eatdirt> 1.5.9-1.mga6
+ Revision: 1037223
- Upgrade to bug fix release 1.5.9

* Tue Mar 08 2016 eatdirt <eatdirt> 1.5.8-1.mga6
+ Revision: 987371
- Upgrade to version 1.5.8

* Thu Mar 03 2016 umeabot <umeabot> 1.5.7-2.mga6
+ Revision: 984690
- Rebuild for openssl

* Sat Dec 19 2015 eatdirt <eatdirt> 1.5.7-1.mga6
+ Revision: 912131
- Upgrade to version 1.5.7

* Sat Oct 24 2015 eatdirt <eatdirt> 1.5.6-2.mga6
+ Revision: 895050
- Fix systemd config files for out-of-the-box compatibility with dnscrypt-proxy

* Thu Oct 22 2015 eatdirt <eatdirt> 1.5.6-1.mga6
+ Revision: 894286
- imported package unbound

